
////////////////////////////////////////////////////////////////
/** <<Google Chart API>> @ google chart style - define*/
// do not show chart tabel at initial point
function drawChart(cityname,chartTableName) {
	// decide to show chart table or not
	// only display the table in 'lulc' mode
	if (chartTableName != null) {
		chartConstructed = true;
		onChartTable();
		
		// control the chart table
		var data = google.visualization.arrayToDataTable(chartTableName);
		var options = {
			title: cityname,
			backgroundColor: 'transparent',
			legend:{
				position: 'top' // 'right'
			}, 
			/*
			// only for google.charts.Bar
			chart: {
				title: 'LULC of Megacities',
				subtitle: 'Based on classification results.'
			},
			chartArea: {
				width: 200,
				height:150
			},
			*/

			hAxis: {
				title: 'Total Area (ha\'000)',
				minValue: 0
			},
			vAxis: {
				//title: 'LULC'
			},

			bars: 'horizontal',
			axes: {
				y: {
					0: {side: 'left'}
				}
			}
		};

		// two types of call function
		//var chart = new google.charts.Bar(document.getElementById('chart_div'));
		var chart = new google.visualization.BarChart(document.getElementById('chart_div'));
		chart.draw(data, options);
		
	} else {
		offChartTable();
	}
}

////////////////////////////////////////////////////////////////
/** <<Google Traffic layer>> @ traffic layer - constructor */
function TrafficConstruct(controlDiv, map, trafficLayer) {
	// Set CSS for the control border
	var trafficUI = document.createElement('div');
	trafficUI.id = 'trafficButtonUI';
	trafficUI.title = 'Click to toggle traffic layer';
	controlDiv.appendChild(trafficUI);

	// Set CSS for the control interior
	var trafficText = document.createElement('div');
	trafficText.id = 'trafficButtonText';
	trafficText.innerHTML = 'Traffic';
	trafficText.style.fontWeight = 'normal';
	trafficUI.appendChild(trafficText);

	// Set up the click event listener for show traffic table
	trafficUI.addEventListener('click', function(){
		var trafficState = trafficLayer.getMap();
		if ( trafficState != null){
			trafficLayer.setMap(null);
			trafficText.style.fontWeight = 'normal';
		} else {
			trafficLayer.setMap(map);
			trafficText.style.fontWeight = 'bold';
		}
	});
}

////////////////////////////////////////////////////////////////
/** <<Google Chart>> @ control the google chart - constructor */
// do not show the chart at first time
var chartConstructed = false;
function ChartConstruct(controlDiv) {
	// Set CSS for the control border
	var chartUI = document.createElement('div');
	chartUI.id = 'chartButtonUI';
	chartUI.title = 'Click to toggle chart UI';
	controlDiv.appendChild(chartUI);

	// Set CSS for the control interior
	var chartText = document.createElement('div');
	chartText.id = 'chartButtonText';
	chartText.innerHTML = 'Statistical Table OFF';
	chartText.style.fontWeight = 'bold';
	chartUI.appendChild(chartText);

	// Set up the click event listener for show chart table
	chartUI.addEventListener('click', function(){
		var ele = document.getElementById("chart_div");
		var text = document.getElementById("chartButtonText");
		if (chartConstructed == true){
			if(ele.style.display == "none") {
				onChartTable();
			}
			else{
				offChartTable();
			}
		}
	});
}
function offChartTable(){
	document.getElementById("chart_div").style.display = "none";
	document.getElementById("chartButtonText").innerHTML = "Statistical Table OFF";
	document.getElementById("chartButtonText").style.fontWeight = 'normal';
}
function onChartTable(){
	document.getElementById("chart_div").style.display = "block";
	document.getElementById("chartButtonText").innerHTML = "Statistical Table ON";
	document.getElementById("chartButtonText").style.fontWeight = 'bold';
}

////////////////////////////////////////////////////////////////
/** <<GridNet>> @ customer overlay grid net - constructor */
function CoordMapType(tileSize) {
	this.tileSize = tileSize;
}
CoordMapType.prototype.getTile = function(coord, zoom, ownerDocument) {
	var div = ownerDocument.createElement('div');
	div.innerHTML = coord;
	div.style.color = 'white';
	div.style.width = this.tileSize.width + 'px';
	div.style.height = this.tileSize.height + 'px';
	div.style.fontSize = '10';
	div.style.borderStyle = 'dashed';
	div.style.borderWidth = '1px';
	div.style.borderColor = '#FFFFFF';
	return div;
};

////////////////////////////////////////////////////////////////
/** <<Basic>> @ basic google map */
var map;
function initMap() {
	/** <<StyleMap>> @ complex styled maps - define*/
	var sisAtlas = new google.maps.StyledMapType(
	[
		{
			elementType: 'labels',
			stylers: [
				{ visibility: 'off' }
			]
		},{
			featureType: 'poi',
			elementType: 'geometry',
			stylers: [
				{ visibility: 'off' }
			]
		},{
			featureType: 'administrative',
			elementType: 'geometry',
			stylers: [
				{ visibility: 'off' }
			]
		},{
			featureType: 'transit',
			elementType: 'geometry',
			stylers: [
				{ visibility: 'off' }
			]
		},{
			featureType: 'water',
			elementType: 'geometry',
			stylers: [
				{ color: '#444444' }
			]
		},{
			featureType: 'landscape',
			elementType: 'geometry',
			stylers: [
				{ color: '#666666' }
			]
		},{
			featureType: 'road',
			elementType: 'geometry',
			stylers: [
				{ color: '#FFFFFF' }
			]
		},{
		}
	], 
	{name: 'MEGA-WEB Road Net'});
	
	/** <<Map>> @ map control - setting */
	// open traditional map control
	//google.maps.controlStyle = 'azteca';
	map = new google.maps.Map(document.getElementById('map'), {
		zoom: 12,
		center: init_pts,
		scaleControl: true,
		zoomControl: true,
		zoomControlOptions: {
			style: google.maps.ZoomControlStyle.LARGE,
			position: google.maps.ControlPosition.RIGHT_CENTER
		},
		streetViewControl: true,
		streetViewControlOptions: {
			position: google.maps.ControlPosition.RIGHT_CENTER
		},
		rotateControl: true,
		rotateControlOptions :{
			position: google.maps.ControlPosition.RIGHT_CENTER
		},
		mapTypeControl: true,
		mapTypeControlOptions: {
			style: google.maps.MapTypeControlStyle.HORIZONTAL_BAR,	// HORIZONTAL_BAR | DROPDOWN_MENU
			position: google.maps.ControlPosition.TOP_LEFT,
			mapTypeIds: [
				/** <<StyleMap>> @ complex styled maps - define*/
				'sisatlas', 
				google.maps.MapTypeId.ROADMAP,
				google.maps.MapTypeId.SATELLITE,
				google.maps.MapTypeId.HYBRID,
				google.maps.MapTypeId.TERRAIN
			]
		}
	});
	
	/** <<StyleMap>> @ complex styled maps - call*/
	map.mapTypes.set('sisatlas', sisAtlas);
	
	// set default map type
	map.setMapTypeId('sisatlas');
	//map.setMapTypeId(google.maps.MapTypeId.TERRAIN);
	
	/** <<GridNet>> @ customer overlay grid net - call*/
	//map.overlayMapTypes.insertAt(0, new CoordMapType(new google.maps.Size(256, 256)));

	initSISBox();
	initSearchBox();
}

/** <<Sis Custom BOX>> @ control the sis custom google layer - call */
function initSISBox() {
	// Create the DIV to hold the control and call the TrafficConstruct()
	// constructor passing in this DIV.
	var trafficLayer = new google.maps.TrafficLayer();
	var trafficControlDiv = document.createElement('div');
	var trafficConstruct = new TrafficConstruct(trafficControlDiv, map, trafficLayer);
	//trafficLayer.setMap(map);

	trafficControlDiv.index = 1;
	map.controls[google.maps.ControlPosition.TOP_LEFT].push(trafficControlDiv);
	
	// Create the DIV to hold the control and call the ChartConstruct()
	// constructor passing in this DIV.
	var chartControlDiv = document.createElement('div');
	var chartConstruct = new ChartConstruct(chartControlDiv);

	chartControlDiv.index = 2;
	map.controls[google.maps.ControlPosition.TOP_LEFT].push(chartControlDiv);
}

/** <<Search Box>> @ auto complete */
function initSearchBox() {
	// Create the search box and link it to the UI element.
	var input = document.getElementById('pac-input');
	var searchBox = new google.maps.places.SearchBox(input);
	map.controls[google.maps.ControlPosition.TOP_LEFT].push(input);

	// Bias the SearchBox results towards current map's viewport.
	map.addListener('bounds_changed', function() {
		searchBox.setBounds(map.getBounds());
	});

	// Listen for the event fired when the user selects a prediction and retrieve
	// more details for that place.
	searchBox.addListener('places_changed', function() {
		var places = searchBox.getPlaces();
		if (places.length == 0) { return; }

		// For each place, get the icon, name and location.
		var bounds = new google.maps.LatLngBounds();
		places.forEach(function(place) {
			if (!place.geometry) {
				console.log("Returned place contains no geometry");
				return;
			}

			if (place.geometry.viewport) {
				// Only geocodes have viewport.
				bounds.union(place.geometry.viewport);
			} else {
				bounds.extend(place.geometry.location);
			}
		});
		map.fitBounds(bounds);
		// need to be discussed?
		map.setZoom(14);
	});
}

////////////////////////////////////////////////////////////////
/** <<Fly to>> @ map jump function */
function flyto(name) {
	var temp_lat = currentCapitalLocation[name + "_lat"];
	var temp_lon = currentCapitalLocation[name + "_lon"];

	var pos = {
		lat: temp_lat,
		lng: temp_lon
	};

	//var infoWindow = new google.maps.InfoWindow({map: map});
	//infoWindow.setPosition(pos);
	map.setCenter(pos);
	map.setZoom(12);

	/** <<Google Chart>> @ control the google chart - call */
	// control the chart table
	var chartTableName = currentKmlObjects[name + "_lulc_change"];
	drawChart(name, chartTableName);
}

////////////////////////////////////////////////////////////////
/** <<Legend>> @ control the legend */
function controlLegend(legendID) {
	switch(legendID) {
		case 0:
			document.getElementById("legend_lulc").style.display="none";
			document.getElementById("legend_lcc").style.display="none";
			document.getElementById("legend_lspop").style.display="none";
			document.getElementById("legend_dmsp").style.display="none";
			document.getElementById("legend_modeling").style.display="none";
			document.getElementById("legend_lst").style.display="none";
			break
		case 1:
			document.getElementById("legend_lulc").style.display="";
			document.getElementById("legend_lcc").style.display="none";
			document.getElementById("legend_lspop").style.display="none";
			document.getElementById("legend_dmsp").style.display="none";
			document.getElementById("legend_modeling").style.display="none";
			document.getElementById("legend_lst").style.display="none";
			break;
		case 2:
			document.getElementById("legend_lulc").style.display="none";
			document.getElementById("legend_lcc").style.display="";
			document.getElementById("legend_lspop").style.display="none";
			document.getElementById("legend_dmsp").style.display="none";
			document.getElementById("legend_modeling").style.display="none";
			document.getElementById("legend_lst").style.display="none";
			break;
		case 3:
			document.getElementById("legend_lulc").style.display="none";
			document.getElementById("legend_lcc").style.display="none";
			document.getElementById("legend_lspop").style.display="";
			document.getElementById("legend_dmsp").style.display="none";
			document.getElementById("legend_modeling").style.display="none";
			document.getElementById("legend_lst").style.display="none";
			break;
		case 4:
			document.getElementById("legend_lulc").style.display="none";
			document.getElementById("legend_lcc").style.display="none";
			document.getElementById("legend_lspop").style.display="none";
			document.getElementById("legend_dmsp").style.display="";
			document.getElementById("legend_modeling").style.display="none";
			document.getElementById("legend_lst").style.display="none";
			break;
		case 5:
			document.getElementById("legend_lulc").style.display="none";
			document.getElementById("legend_lcc").style.display="none";
			document.getElementById("legend_lspop").style.display="none";
			document.getElementById("legend_dmsp").style.display="none";
			document.getElementById("legend_modeling").style.display="";
			document.getElementById("legend_lst").style.display="none";
			break;
		case 6:
			document.getElementById("legend_lulc").style.display="none";
			document.getElementById("legend_lcc").style.display="none";
			document.getElementById("legend_lspop").style.display="none";
			document.getElementById("legend_dmsp").style.display="none";
			document.getElementById("legend_modeling").style.display="none";
			document.getElementById("legend_lst").style.display="";
			break;
	}
}

